#!/bin/sh
set -x

export PATH=$SPARK_HOME/bin:$PATH
export HADOOP_CONF_DIR=/etc/taihao-apps/hadoop-conf
export JAVA_HOME=/usr/lib/jvm/java-1.8.0

sh_path=$(cd $(dirname $0); pwd)
source ${sh_path}/00_common.sh

# 评测结果保存路径，后续需要根据此文件评估是否要更新模型
predict_analyse_file_path=/root/zhaohp/XGB/predict_analyse_file/20241105_351_1000_analyse.txt

# 保存模型评估的分析结果
old_incr_rate_avg=0
new_incr_rate_avg=0

top10_msg=""


calc_model_predict() {
  local count=0
  local max_line=10
  local old_total_diff=0
  local new_total_diff=0
  top10_msg="| CID  | 老模型相对真实CTCVR的变化 | 新模型相对真实CTCVR的变化 |"
  top10_msg+=" \n| ---- | --------- | -------- |"
  while read -r line && [ ${count} -lt ${max_line} ]; do

      # 使用 ! 取反判断，只有当行中不包含 "cid" 时才执行继续的逻辑
      if [[ "${line}" == *"cid"* ]]; then
          continue
      fi

      read -a numbers <<< "${line}"

      # 分数分别保存
      real_score_map[${numbers[0]}]=${numbers[3]}
      old_score_map[${numbers[0]}]=${numbers[6]}
      new_score_map[${numbers[0]}]=${numbers[7]}

      # 拼接Top10详情的飞书消息
      top10_msg="${top10_msg} \n| ${numbers[0]} | ${numbers[6]} | ${numbers[7]} | "

      # 计算top10相对误差绝对值的均值
      old_abs_score=$( echo "${numbers[6]} * ((${numbers[6]} >= 0) * 2 - 1)" | bc -l )
      new_abs_score=$( echo "${numbers[7]} * ((${numbers[7]} >= 0) * 2 - 1)" | bc -l )

      old_total_diff=$( echo "${old_total_diff} + ${old_abs_score}" | bc -l )
      new_total_diff=$( echo "${new_total_diff} + ${new_abs_score}" | bc -l )

      count=$((${count} + 1))

  done < "${predict_analyse_file_path}"

  old_incr_rate_avg=$( echo "scale=6; ${old_total_diff} / ${count}" | bc -l )

  new_incr_rate_avg=$( echo "scale=6; ${new_total_diff} / ${count}" | bc -l )

  echo "老模型Top10差异平均值: ${old_incr_rate_avg}"
  echo "新模型Top10差异平均值: ${new_incr_rate_avg}"
  echo "新老模型分数对比: "
  for cid in "${!new_score_map[@]}"; do
    echo "\t CID: $cid, 老模型分数: ${old_score_map[$cid]}, 新模型分数: ${new_score_map[$cid]}"
  done
}


calc_model_predict